# LTGN
Loss Trim Graph-based Network (LTGN), an unsupervised framework based on the interpretability of graph neural networks.

# Installation
The LTGN package is developed based on the Python libraries PyTorch and PyG (PyTorch Geometric) framework, and can be run on GPU (recommend) or CPU. Before installing stVGP, please ensure that PyTorch, and PyG (PyTorch Geometric) are already installed. These dependencies are required for LTGN to function properly, but they are not automatically installed during the installation process to allow greater flexibility.
    
    # Installation
    pip install LTGN

# Quick-start tutorial
Here, we provide guidance on using the LTGN sample data to help you quickly get started with our method. 
